@@ -72,7 +72,7 @@ class BackTest_DF(object):
         self.end_date=self.signal['date'].max() 
         self.close_hfq = close_hfq
         self.close_hfq.index = pd.to_datetime(self.close_hfq.index)
-        if other_close:
+        if len(other_close):
             self.ZS_close = other_close.copy()
             self.ZS_close.index = pd.to_datetime(self.ZS_close.index)
             self.ZS_close.index=self.close_hfq.index
